@@ -30,13 +30,13 @@ class Q_DECL_EXPORT Active_window_condition : public QObject, public Condition
 public:
     Active_window_condition(Windowdef_list *window_P, Condition_list_base *parent_P = nullptr);
     Active_window_condition(KConfigGroup &cfg_P, Condition_list_base *parent_P);
-    virtual ~Active_window_condition();
-    bool match() const Q_DECL_OVERRIDE;
-    void cfg_write(KConfigGroup &cfg_P) const Q_DECL_OVERRIDE;
+    ~Active_window_condition() override;
+    bool match() const override;
+    void cfg_write(KConfigGroup &cfg_P) const override;
     const Windowdef_list *window() const;
     Windowdef_list *window();
-    Active_window_condition *copy() const Q_DECL_OVERRIDE;
-    const QString description() const Q_DECL_OVERRIDE;
+    Active_window_condition *copy() const override;
+    const QString description() const override;
 public Q_SLOTS:
     void active_window_changed(WId);
 
